---
page_title: Mikula Sample Gallery Blog - Recent
date: 2021-08-15
permalink: most-recent
title: Recent post in which the author shares his thoughts on modern blog post writing and life in general
thumbnail: dog.jpg
---

# Recent

It's very easy to make some words **bold** and other words _italic_ with Markdown. You can even link to [Mikula](https://github.com/RomanKosobrodov/mikula)!

## Section 1.1

This is subsection of the recent post

### Section 1.1.1

This is subsection of Section 1.1.

## Emphasis

_This text will be italic_
_This will also be italic_

**This text will be bold**
**This will also be bold**

_You **can** combine them_

## Lists

They can be unordered

- Item 1
- Item 2
  - Item 2a
  - Item 2b

And ordered

1. Item 1
1. Item 2
1. Item 3
   1. Item 3a
   1. Item 3b

## Backquotes

> But man is not made for defeat.
> A man can be destroyed but not defeated.

Ernest Hemingway

## Images

Images can be stored in the same folder as this markdown file:

![Dog Image](dog.jpg "dog by Gustavo Zambelli on Unsplash")

(Photo by <a href="https://unsplash.com/@zamax?utm_source=unsplash&utm_medium=referral&utm_content=creditCopyText">Gustavo Zambelli</a> on <a href="https://unsplash.com/?utm_source=unsplash&utm_medium=referral&utm_content=creditCopyText">Unsplash</a>)

Alternatively, a path relative to the directory containing current markdown file can be given

![Camp Fire Image](blog-assets/recent-thumbnail.jpg "camp fire")

Photo by <a href="https://unsplash.com/@hip_dinosaur?utm_source=unsplash&utm_medium=referral&utm_content=creditCopyText">Nathan Lindahl</a> on <a href="https://unsplash.com/s/photos/campfire?utm_source=unsplash&utm_medium=referral&utm_content=creditCopyText">Unsplash</a>
  
